/* SAS/C compitibility

This function locates a file in the currently defined path. If the process is
not a Shell process, it uses the path in effect when Workbench was loaded.

If the findpath function finds the file, it returns a lock on that directory
even if it is the current directory. The lock must be unlocked with the
AmigaDOS UnLock function. If the findpath function cannot find the file,
it returns a -1. The value NULL is not used because NULL is a valid lock.

*/

#include <proto/dos.h>

void* findpath(const char *filename)
{
    BPTR file = Lock(filename, SHARED_LOCK);

    if (file <= 0)
    {
	struct CommandLineInterface *cli = Cli();
        BPTR oldCurDir = CurrentDir(NULL);
	BPTR *paths = BADDR(cli->cli_CommandDir);

        if (IoErr() == ERROR_OBJECT_IN_USE)
          return -1;

        for (; !file && paths; paths = BADDR(paths[0]))
        {
            CurrentDir(paths[1]);
            file = Lock(filename, SHARED_LOCK);
        }

	CurrentDir(oldCurDir);
    }

    if (file > 0)
    {
	BPTR dir = ParentOfFH(file);
	UnLock(file);
	file = dir;
    }

    return file ? file : -1;
}
